ValidateUserID

Trait ValidateUserID 

pub trait ValidateUserID<'s, S: SOP<'s>, Certs: Load<'s, S>> {
    // Required methods
    fn trust_roots(
        self: Box<Self>,
        certs: &Certs,
    ) -> Result<Box<dyn ValidateUserID<'s, S, Certs> + 's>>;
    fn target_certs(
        self: Box<Self>,
        certs: &Certs,
    ) -> Result<Box<dyn ValidateUserID<'s, S, Certs> + 's>>;
    fn validate_at(
        self: Box<Self>,
        at: SystemTime,
    ) -> Result<Box<dyn ValidateUserID<'s, S, Certs> + 's>>;
    fn userid(self: Box<Self>, userid: &str) -> Result<()>;
    fn email(self: Box<Self>, email: &str) -> Result<()>;
}
Builder for SOP::validate_userid.

Required Methods

fn trust_roots( self: Box<Self>, certs: &Certs, ) -> Result<Box<dyn ValidateUserID<'s, S, Certs> + 's>>

Supplies authority OpenPGP certificates, i.e. trust roots.

fn target_certs( self: Box<Self>, certs: &Certs, ) -> Result<Box<dyn ValidateUserID<'s, S, Certs> + 's>>

Tests that these certificates have the given User ID.

fn validate_at( self: Box<Self>, at: SystemTime, ) -> Result<Box<dyn ValidateUserID<'s, S, Certs> + 's>>

Evaluate the validity of the User ID at the specified time, not at the current time.

fn userid(self: Box<Self>, userid: &str) -> Result<()>

Validates an User ID.

fn email(self: Box<Self>, email: &str) -> Result<()>

Validates an email address.

Matched only against the e-mail address part of each correctly bound User ID.

Implementors